.. pqdict documentation master file, created by
   sphinx-quickstart on Tue Nov 19 04:17:17 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation for pqdict |release|
==================================

Contents:

.. toctree::
   :maxdepth: 2

   Introduction <intro>

   examples

   pqdict


* :ref:`genindex`
* :ref:`search`

